@@ -1,5 +1,6 @@
 package List::Compare::Functional;
-$VERSION = 0.32;   # September 18, 2005 
+#$Id: Functional.pm 1305 2008-05-18 23:58:27Z jimk $
+$VERSION = 0.35;
 @ISA = qw(Exporter);
 @EXPORT_OK = qw|
     get_intersection
@@ -389,7 +390,7 @@ sub print_equivalence_chart {
 sub _print_equivalence_chart_engine {
     my $seenrefsref = _calc_seen1(@_);
     my $xequivalentref = _equivalent_subengine($seenrefsref);
-    my $title = 'Subset';
+    my $title = 'Equivalence';
     _chart_engine_multiple($xequivalentref, $title);
 }    
 
@@ -494,7 +495,9 @@ sub _bag_engine {
                 push(@bag, $el);
             }
         }
-    } elsif (ref($listrefs[0]) eq 'HASH') {
+    } else {
+        # Via _argument_checker_0(), we've already guaranteed that we
+        # have either array refs or hash refs.
         foreach my $lref (@listrefs) {
             foreach my $key (keys %{$lref}) {
                 for (my $j=1; $j <= ${$lref}{$key}; $j++) {
@@ -502,8 +505,6 @@ sub _bag_engine {
                 }
             }
         }
-    } else {
-        croak "Indeterminate case in _bag_engine: $!";
     }
     return \@bag;
 }
@@ -522,8 +523,8 @@ List::Compare::Functional - Compare elements of two or more lists
 
 =head1 VERSION
 
-This document refers to version 0.32 of List::Compare::Functional.  
-This version was released September 18, 2005.  The first released 
+This document refers to version 0.35 of List::Compare::Functional.  
+This version was released May 18, 2008.  The first released 
 version of List::Compare::Functional was v0.21.  Its version numbers 
 are set to be consistent with the other parts of the List::Compare 
 distribution.
@@ -1687,7 +1688,7 @@ James E. Keenan (jkeenan@cpan.org).  When sending correspondence, please
 include 'List::Compare::Functional' or 'List-Compare-Functional' in your 
 subject line.
 
-Creation date:  May 20, 2002.  Last modification date:  September 18, 2005. 
+Creation date:  May 20, 2002.  Last modification date:  May 18, 2008. 
 Copyright (c) 2002-04 James E. Keenan.  United States.  All rights reserved. 
 This is free software and may be distributed under the same terms as Perl
 itself.
